[![PyPI version](https://badge.fury.io/py/easys-ordermanager.svg)](https://badge.fury.io/py/easys-ordermanager)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Lektor.svg)](https://pypi.org/project/easys-ordermanager/)

# EasyS order manager API

## Compatibility matrix

Python 3.8, 3.9 and 3.10 

### Django 3.2

DRF 3.11 or newer

### Django 4.0

DRF 3.13 or newer

### Django 4.1

DRF 3.14 or newer
